@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: FLEXI-STREAMS; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/flexi-streams/external-format.lisp,v 1.8 2006/10/31 14:09:08 edi Exp $
+;;; $Header: /usr/local/cvsrep/flexi-streams/external-format.lisp,v 1.11 2007/01/01 23:46:49 edi Exp $
 
-;;; Copyright (c) 2005-2006, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2005-2007, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -119,24 +119,29 @@ encoding."
          (eq (external-format-eol-style ef1)
              (external-format-eol-style ef2)))))
 
+(defun normalize-external-format (external-format)
+  "Returns a list which is a `normalized' representation of the
+external format EXTERNAL-FORMAT.  Used internally by
+PRINT-OBJECT, for example.  Basically, the result is argument
+list that can be fed back to MAKE-EXTERNAL-FORMAT to create an
+equivalent object."
+  (let ((name (external-format-name external-format))
+        (eol-style (external-format-eol-style external-format)))
+    (cond ((or (ascii-name-p name)
+               (koi8-r-name-p name)
+               (iso-8859-name-p name)
+               (eq name :utf-8))
+           (list name :eol-style eol-style))
+          ((code-page-name-p name)
+           (list name
+                 :id (external-format-id external-format)
+                 :eol-style eol-style))
+          (t (list name
+                   :eol-style eol-style
+                   :little-endian (external-format-little-endian external-format))))))
+
 (defmethod print-object ((object external-format) stream)
-  "How an EXTERNAL-FORMAT object is rendered.  Basically, it
-shows an argument list that can be fed back to
-MAKE-EXTERNAL-FORMAT to create an equivalent object."
+  "How an EXTERNAL-FORMAT object is rendered.  Uses
+NORMALIZE-EXTERNAL-FORMAT."
   (print-unreadable-object (object stream :type t :identity t)
-    (let ((name (external-format-name object))
-          (eol-style (external-format-eol-style object)))
-      (prin1
-       (cond ((or (ascii-name-p name)
-		  (koi8-r-name-p name)
-                  (iso-8859-name-p name)
-                  (eq name :utf-8))
-              (list name :eol-style eol-style))
-             ((code-page-name-p name)
-              (list name
-                    :id (external-format-id object)
-                    :eol-style eol-style))
-             (t (list name
-                      :eol-style eol-style
-                      :little-endian (external-format-little-endian object))))
-       stream))))
\ No newline at end of file
+    (prin1 (normalize-external-format object) stream)))
\ No newline at end of file
