@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: FLEXI-STREAMS; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/flexi-streams/input.lisp,v 1.47 2007/03/22 21:40:11 edi Exp $
+;;; $Header: /usr/local/cvsrep/flexi-streams/input.lisp,v 1.48 2007/09/06 23:19:24 edi Exp $
 
 ;;; Copyright (c) 2005-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -39,10 +39,15 @@ empty)."
   ;; issue with SBCL:
   ;; <http://article.gmane.org/gmane.lisp.steel-bank.general/1386>
   (with-accessors ((position flexi-stream-position)
+                   (bound flexi-stream-bound)
                    (octet-stack flexi-stream-octet-stack)
                    (s flexi-stream-stream))
       flexi-input-stream
-    (declare (integer position))
+    (declare (integer position)
+             (type (or null integer) bound))
+    (when (and bound
+               (>= position bound))
+      (return-from read-byte* nil))
     (incf position)
     (or (pop octet-stack)
         (read-byte s nil nil)
@@ -55,10 +60,15 @@ FLEXI-OUTPUT-STREAM \(or from the internal stack if it's not
 empty)."
   (declare (optimize speed))
   (with-accessors ((position flexi-stream-position)
+                   (bound flexi-stream-bound)
                    (octet-stack flexi-stream-octet-stack)
                    (stream flexi-stream-stream))
       flexi-input-stream
-    (declare (integer position))
+    (declare (integer position)
+             (type (or null integer) bound))
+    (when (and bound
+               (>= position bound))
+      (return-from read-byte* nil))
     (incf position)
     (or (pop octet-stack)
         ;; we use READ-SEQUENCE because READ-BYTE doesn't work with all
@@ -77,10 +87,15 @@ Optimized version \(only needed for LispWorks) in case the underlying
 stream is binary."
   (declare (optimize speed))
   (with-accessors ((position flexi-stream-position)
+                   (bound flexi-stream-bound)
                    (octet-stack flexi-stream-octet-stack)
                    (stream flexi-stream-stream))
       flexi-input-stream
-    (declare (integer position))
+    (declare (integer position)
+             (type (or null integer) bound))
+    (when (and bound
+               (>= position bound))
+      (return-from read-byte* nil))
     (incf position)
     (or (pop octet-stack)
         (read-byte stream nil nil)
@@ -99,12 +114,17 @@ and also clears the value of the OCTET-STACK slot."
 
 (defmethod stream-listen ((flexi-input-stream flexi-input-stream))
   "Calls the corresponding method for the underlying input stream
-but first check if \(old) input is available in the OCTET-STACK
+but first checks if \(old) input is available in the OCTET-STACK
 slot."
   (declare (optimize speed))
-  (with-accessors ((octet-stack flexi-stream-octet-stack)
+  (with-accessors ((position flexi-stream-position)
+                   (bound flexi-stream-bound)
+                   (octet-stack flexi-stream-octet-stack)
                    (stream flexi-stream-stream))
       flexi-input-stream
+    (when (and bound
+               (>= position bound))
+      (return-from stream-listen nil))
     (or octet-stack (listen stream))))
 
 (defmethod stream-read-byte ((stream flexi-input-stream))
