@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: FLEXI-STREAMS; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/flexi-streams/stream.lisp,v 1.48 2007/01/01 23:46:49 edi Exp $
+;;; $Header: /usr/local/cvsrep/flexi-streams/stream.lisp,v 1.50 2007/09/06 23:46:29 edi Exp $
 
 ;;; Copyright (c) 2005-2007, Dr. Edmund Weitz.  All rights reserved.
 
@@ -200,7 +200,14 @@ look ahead for a CR/LF line ending.")
              :type integer
              :accessor flexi-stream-position
              :documentation "The position within the stream where each
-octet read counts as one."))
+octet read counts as one.")
+   (bound :initform nil
+          :initarg :bound
+          :type (or null integer)
+          :accessor flexi-stream-bound
+          :documentation "When this is not NIL, it must be an integer
+and the stream will behave as if no more data is available as soon as
+POSITION is greater or equal than this value."))
   (:documentation "A FLEXI-INPUT-STREAM is a FLEXI-STREAM that
 can actually be instatiated and used for input.  Don't use
 MAKE-INSTANCE to create a new FLEXI-INPUT-STREAM but use
@@ -686,7 +693,7 @@ on its external format."
 
 (defun make-flexi-stream (stream &rest args
                                  &key (external-format (make-external-format :iso-8859-1))
-                                      element-type column position)
+                                      element-type column position bound)
   "Creates and returns a new flexi stream.  STREAM must be an open
 binary or `bivalent' stream, i.e. it must be capable of
 reading/writing octets with READ-SEQUENCE and/or WRITE-SEQUENCE.  The
@@ -696,13 +703,16 @@ is an output stream.  The default for ELEMENT-TYPE is LW:SIMPLE-CHAR
 on LispWorks and CHARACTER on other Lisps.  EXTERNAL-FORMAT must be an
 EXTERNAL-FORMAT object or a symbol or a list denoting such an object.
 COLUMN is the initial column of the stream which is either a
-non-negative integer or NIL.  The COLUMN argument is only used for
-output streams.  POSITION \(only used for input streams) should be an
-integer and it denotes the position the stream is in - it will be
-increased by one for each octet read."
+non-negative integer or NIL.  The COLUMN argument must only be used
+for output streams.  POSITION \(only used for input streams) should be
+an integer and it denotes the position the stream is in - it will be
+increased by one for each octet read.  BOUND \(only used for input
+streams) should be NIL or an integer.  If BOUND is not NIL and
+POSITION has gone beyond BOUND, then the stream will behave as if no
+more input is available."
   ;; these arguments are ignored - they are only there to provide a
   ;; meaningful parameter list for IDEs
-  (declare (ignore element-type column position))
+  (declare (ignore element-type column position bound))
   (unless (and (streamp stream)
                (open-stream-p stream))
     (error "~S should have been an open stream." stream))
